@@ -421,13 +421,12 @@ class RESTAPI :
             RIOT_KEY = 'RGAPI-ef3247df-953a-4361-80f7-f3f2c255b5d0'
             r_api = RiotApi(RIOT_KEY, REGIONS['north_america'])
             summoner = r_api.get_summoner_by_puuid(puuid)
-            league = self.get_league_by_summonerid(summoner['id'])
-            print(league)
-            if len(league) == [] :
+            leagues = self.get_league_by_summonerid(summoner['id'])
+            if len(leagues) == 0 or leagues == [] :
                 api_url=URL['leagues'].format(url='/')
                 league = r_api.get_league_by_summoner_id(summoner['id'])
                 print(league)
-                self.post_league(league)
+                self.post_league(league[0])
 
             championMastery = self.get_championmastery_by_championid_and_summonerid(body['championid'], summoner['id'])
             print(championMastery)
